/*-
 * See the file LICENSE for redistribution information.
 *
 * Copyright (c) 2002-2009 Oracle.  All rights reserved.
 *
 * $Id: MonitorChangeListener.java,v 1.9 2009/06/16 21:14:43 sam Exp $
 */

package com.sleepycat.je.rep.monitor;

/**
 * Applications can register for Monitor event notification through {@link
 * Monitor#startListener}. The interface defines an overloaded notify event for
 * each event supported by the Monitor. Subclasses of Monitor override the
 * method that's of interest to them.
 */
public interface MonitorChangeListener {

    /**
     * The method is invoked whenever there is new master associated with the
     * replication group. The method should be light weight and should return
     * control back to the invoker as soon as possible, so that any subsequent
     * changes that might be queued can be communicated to the application.
     *
     * If the method throws an exception, JE will log the exception as a trace
     * message, which will be propagated through the usual channels.
     *
     * @param newMasterEvent the event that resulted in the notify. It
     * describes the new master.
     */
    public void notify(NewMasterEvent newMasterEvent);

    /**
     * The method is invoked whenever there is a change to the composition of
     * the replication group. The method should be light weight and should
     * return control back to the invoker as soon as possible, so that any
     * subsequent changes that might be queued can be communicated to the
     * application.
     *
     * If the method throws an exception, JE will log the exception as a trace
     * message, which will be propagated through the usual channels.
     *
     * @param groupChangeEvent the event that resulted in the notify. It
     * describes the group.
     */
    public void notify(GroupChangeEvent groupChangeEvent);
}
