/*-
 * See the file LICENSE for redistribution information.
 *
 * Copyright (c) 2002-2009 Oracle.  All rights reserved.
 *
 * $Id: ConsoleHandler.java,v 1.6 2009/10/02 04:13:59 linda Exp $
 */

package com.sleepycat.je.util;

import java.util.logging.Formatter;
import java.util.logging.Level;

import com.sleepycat.je.utilint.LoggerUtils;

/**
 * JE instances of java.util.logging.Logger are configured to use this
 * implementation of java.util.logging.ConsoleHandler. By default, the
 * handler's level is {@link Level#OFF}. To enable the console output, use the
 * standard java.util.logging.LogManager configuration to set the desired
 * level:
 * <pre>
 * com.sleepycat.je.util.ConsoleHandler.level=ALL
 * </pre>
 * @see <a href="{@docRoot}/../ReplicationGuide/logging.html">Replication Guide, Logging</a> 
 * @see <a href="{@docRoot}/../traceLogging.html">Using JE Trace Logging</a>
 */
public class ConsoleHandler extends java.util.logging.ConsoleHandler {
    
    /* 
     * Using a JE specific handler lets us enable and disable output for the
     * entire library, and specify an environment specific format.
     */
    public ConsoleHandler(Formatter formatter) {
        super();

        /* Messages may be formatted with an environment specific tag. */
        setFormatter(formatter);

        /* The default level is OFF. */
        String levelName = getClass().getName() + ".level";
        String levelProperty = LoggerUtils.getLoggerProperty(levelName);
        if (levelProperty == null) {
            setLevel(Level.OFF);
        }
    }
}

